==> zio-aws-cognitoidentity_3-5.17.153.3-sources.jar: zio/aws/cognitoidentity/model/GetIdResponse.scala <==
package zio.aws.cognitoidentity.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cognitoidentity.model.primitives.IdentityId
import scala.jdk.CollectionConverters.*
final case class GetIdResponse(identityId: Option[IdentityId] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cognitoidentity.model.GetIdResponse = {
    import GetIdResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cognitoidentity.model.GetIdResponse
      .builder()
      .optionallyWith(
        identityId.map(value => IdentityId.unwrap(value): java.lang.String)
      )(_.identityId)
      .build()
  }
  def asReadOnly: zio.aws.cognitoidentity.model.GetIdResponse.ReadOnly =
    zio.aws.cognitoidentity.model.GetIdResponse.wrap(buildAwsValue())
}
object GetIdResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cognitoidentity.model.GetIdResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cognitoidentity.model.GetIdResponse =
      zio.aws.cognitoidentity.model
        .GetIdResponse(identityId.map(value => value))
    def identityId: Option[IdentityId]
    def getIdentityId: ZIO[Any, AwsError, IdentityId] =
      AwsError.unwrapOptionField("identityId", identityId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cognitoidentity.model.GetIdResponse
  ) extends zio.aws.cognitoidentity.model.GetIdResponse.ReadOnly {
    override val identityId: Option[IdentityId] = scala
      .Option(impl.identityId())
      .map(value => zio.aws.cognitoidentity.model.primitives.IdentityId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.cognitoidentity.model.GetIdResponse
  ): zio.aws.cognitoidentity.model.GetIdResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-cognitoidentity_3-5.17.195.2-sources.jar: zio/aws/cognitoidentity/model/GetIdResponse.scala <==
package zio.aws.cognitoidentity.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.cognitoidentity.model.primitives.IdentityId
import scala.jdk.CollectionConverters.*
final case class GetIdResponse(
    identityId: Optional[IdentityId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cognitoidentity.model.GetIdResponse = {
    import GetIdResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cognitoidentity.model.GetIdResponse
      .builder()
      .optionallyWith(
        identityId.map(value => IdentityId.unwrap(value): java.lang.String)
      )(_.identityId)
      .build()
  }
  def asReadOnly: zio.aws.cognitoidentity.model.GetIdResponse.ReadOnly =
    zio.aws.cognitoidentity.model.GetIdResponse.wrap(buildAwsValue())
}
object GetIdResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cognitoidentity.model.GetIdResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cognitoidentity.model.GetIdResponse =
      zio.aws.cognitoidentity.model
        .GetIdResponse(identityId.map(value => value))
    def identityId: Optional[IdentityId]
    def getIdentityId: ZIO[Any, AwsError, IdentityId] =
      AwsError.unwrapOptionField("identityId", identityId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cognitoidentity.model.GetIdResponse
  ) extends zio.aws.cognitoidentity.model.GetIdResponse.ReadOnly {
    override val identityId: Optional[IdentityId] = zio.aws.core.internal
      .optionalFromNullable(impl.identityId())
      .map(value => zio.aws.cognitoidentity.model.primitives.IdentityId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.cognitoidentity.model.GetIdResponse
  ): zio.aws.cognitoidentity.model.GetIdResponse.ReadOnly = new Wrapper(impl)
}
